@@ -10,9 +10,6 @@
 #'
 #' \code{vignette(topic = "export", package = "REDCapExporter")}
 #'
-#' @importFrom data.table as.data.table
-#'
-#' @docType package
-#' @name REDCapExporter
-NULL
+#' @keywords internal
+"_PACKAGE"
 
